Kirlent
=======

Tools for building educational material.

Dependencies
------------

- kirlent_docutils for ImpressJS and RevealJS slides.
- decktape for PDF slides.
- pdfjam for n-up PDF documents.
